@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20220331';
+our $VERSION = '0.20220428';
 
-# Table last modified: 2022-03-31
+# Table last modified: 2022-04-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,14 +103,14 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|6[05689]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-8]|3[013568]|1[013-7])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|7[12468]|8[124-9]|2[013-8]|4[014]|0[1-57-9]|6[05689]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-9]|3[013568]|1[013-7])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|7[014-689]|3[0-589]|5[18])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|5[06]|8[05]|7[08]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
     '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|5[013-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
@@ -133,14 +133,14 @@ our %ZIP_TABLE = (
     '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[13]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[0-58]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|5[128]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|1[1256])|6(?:01|4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:01|4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:1[1-689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|0[135]|5[158]|8[058]|1[0-25]|7[67]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
-    '150' => '(?:8(?:5(?:45|6[37]|2[256]|7[57]|8[578]|1[0-24-7]|5[1-5]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|3[0368]|8[45]|0[167]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|4[03]|7[37]|3[0368]|8[45]|0[167]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|[24][0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|3[0169]|1[02568])|6(?:01|40|1[06]|8[78]|2[02]|6[025689]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
@@ -198,7 +198,7 @@ our %ZIP_TABLE = (
     '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
     '211' => '(?:8(?:5(?:40|66|3[03]|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
     '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[23]))',
-    '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|8[016-9]|1[125-7]|3[35]|7[0367]))',
+    '213' => '(?:85(?:66|0[2357]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]|8[06-9]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
@@ -246,7 +246,7 @@ our %ZIP_TABLE = (
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
-    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|85(?:[0-2]1|55)|019[24-8]))',
+    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
     '271' => '(?:8(?:5(?:01|22|3[03]|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
     '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|019[35]))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|27)|7(?:10|33))|019[2357]))',
@@ -303,7 +303,7 @@ our %ZIP_TABLE = (
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[238]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|6[24-6]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:10|77))))',
+    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|6[24-6]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
@@ -332,7 +332,7 @@ our %ZIP_TABLE = (
     '356' => '(?:85(?:25|33|67|0[127]|5[056]|8[05]|1[01]))',
     '357' => '(?:85(?:[17]0|01|27|5[058]|8[58]))',
     '358' => '(?:85(?:[02]1|1[015]|[58][58]))',
-    '359' => '(?:(?:8(?:5(?:[267]0|33|42|5[058]|1[013]|8[05]|0[157])|6(?:01|48|86))|11(?:9[2356]|8[089])))',
+    '359' => '(?:(?:8(?:5(?:[267]0|33|42|5[058]|1[013]|8[05]|0[157])|6(?:01|48|86))|11(?:9[23568]|8[089])))',
     '360' => '(?:(?:8(?:5(?:[67]7|32|43|2[0-3]|1[25]|8[05]|0[12]|5[589])|6(?:11|20|0[18]))|019[2-7]))',
     '361' => '(?:8(?:5(?:[58]5|39|1[013]|0[3-8])|60[1-4]))',
     '362' => '(?:8(?:5(?:[67]7|42|0[148]|3[19]|2[013]|8[58]|5[035]|1[017])|688))',
@@ -431,8 +431,8 @@ our %ZIP_TABLE = (
     '457' => '(?:8(?:5(?:22|45|77|3[0-35]|5[158]|1[0-25]|6[067]|8[58]|0[18])|71[12]))',
     '458' => '(?:85(?:30|55|8[015]|0[1258]|1[05]|2[0-2]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
-    '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|7[578]|0[13-9]|4[15]|6[06-8])|6(?:90|7[0-2489]|0[2568]|2[13568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|[08][1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
-    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-249]|0[13-8]|7[57]|1[126]|4[01])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
+    '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|7[578]|0[13-9]|4[15]|6[06-8])|6(?:90|7[0-2489]|2[135-8]|0[2568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|[08][1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
+    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-249]|0[13-8]|7[57]|1[12]|4[01])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08]|4[035])|666|739))',
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|91|4[05-7]|5[058]|2[0-25]|1[12]|6[0167]|3[01369]|7[017])|6(?:[78]1|0[1-3]|4[134]|3[1-357]|6[12]|1[0135-7]|5[0-24])|710))',
@@ -568,7 +568,7 @@ our %ZIP_TABLE = (
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:44|3[03]|2[056]|6[5-7]|1[19]|5[058]|8[1568]|0[1-356]|7[07])|6(?:52|65|8[68])|7(?:11|87|92)))',
     '601' => '(?:(?:8(?:5(?:[26]0|42|88|3[03]|5[09]|0[126]|1[01])|601)|1(?:192|397|495)|0(?:292|797)))',
-    '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|611))',
+    '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|6(?:02|11)))',
     '603' => '(?:85(?:11|22|55|77|88))',
     '604' => '(?:8(?:5(?:[24]0|1[015]|0[1258]|8[058]|7[178]|6[07]|5[01568])|666|798))',
     '605' => '(?:8(?:5(?:11|0[15])|686))',
@@ -581,7 +581,7 @@ our %ZIP_TABLE = (
     '614' => '(?:85(?:[01]1|88))',
     '615' => '(?:8(?:5(?:[34]0|01|77|85|2[02]|5[58]|1[01])|6[68]6))',
     '616' => '(?:8(?:5(?:[01]1|33|55|66|8[56])|666))',
-    '617' => '(?:8(?:5(?:[01]1|[23]0|66|77|5[015]|8[58])|66[56]|772))',
+    '617' => '(?:8(?:5(?:[01]1|[23]0|66|77|5[015]|8[58])|6(?:17|6[56])|772))',
     '618' => '(?:85(?:[28]5|67|70|5[58]|1[18]|0[12]))',
     '619' => '(?:(?:02(?:9[245]|8[02-9])|1(?:[12]95|393)))',
     '620' => '(?:(?:850[1-8]|149[23]))',
@@ -934,7 +934,7 @@ our %ZIP_TABLE = (
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[25-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
-    '980' => '(?:(?:8(?:4(?:7[78]|[04][1-35-8]|8[014-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|4[3-6]|7\d|2[01569]|0[158]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
+    '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|4[3-6]|7\d|2[01569]|0[158]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|6[03]|5[0-26-8]|0[25]|7[07]|2[235]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
     '983' => '(?:8(?:5(?:70|85|6[0257]|0[1247]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
